using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using SWOG_GiveCamp.Entities;
using SWOG_GiveCamp.Models;

namespace SWOG_GiveCamp.Controllers
{   
    public class CharityController : Controller
    {
		private readonly ICharityRequirementRepository charityrequirementRepository;

		// If you are using Dependency Injection, you can delete the following constructor
        public CharityController() : this(new CharityRequirementRepository())
        {
        }

        public CharityController(ICharityRequirementRepository charityrequirementRepository)
        {
			this.charityrequirementRepository = charityrequirementRepository;
        }

        //
        // GET: /Charity/
        [Authorize(Roles = "Administrator")]
        public ViewResult Review()
        {
            return View(charityrequirementRepository.AllIncluding(charityrequirement => charityrequirement.StaffTechnologies, charityrequirement => charityrequirement.ProjectTechnologies));
        }
        public ViewResult Grid()
        {
            return View(charityrequirementRepository.AllIncluding(charityrequirement => charityrequirement.StaffTechnologies, charityrequirement => charityrequirement.ProjectTechnologies));
        }
        public ViewResult Index()
        {
            return View();
        }

        //
        // GET: /Charity/Details/5
        public ActionResult OnlineForm()
        {
            var file = Path.Combine(Server.MapPath("~/Public"), "Charity Proposal Form.docx");
            FileInfo info = new FileInfo(file);
            if (info.Exists)
            {
                return File(file, "application/msword","SWOGC_CharitySubmissionForm.docx");
            }
            else
            {
                return RedirectToAction("HttpError404", "Error");
            }
        }
        public ViewResult Details(int id)
        {
            var charity = charityrequirementRepository.Find(id);
            return View(charity);
        }

        //
        // GET: /Charity/Create
        public ActionResult Signup()
        {
            return RedirectToAction("Create");
        } 
        public ActionResult Create()
        {
            return View("Closed");
        } 

        //
        // POST: /Charity/Create

        [HttpPost, ValidateInput(false)]
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Exclude = "CharityRequirementId")]CharityRequirementVM charityrequirementVM)
        {
            if (TryValidateModel(charityrequirementVM.CharityRequirement))
            {
                charityrequirementRepository.InsertOrUpdate(charityrequirementVM.CharityRequirement);
                charityrequirementRepository.Save();
                ViewBag.Email = charityrequirementVM.Email;
                Models.MailRepo repo = new MailRepo();
                repo.SendCharityAcknowledgement(charityrequirementVM);
                return View("Congratulations");
            }
            else return View(charityrequirementVM);
        }
        
        //
        // GET: /Charity/Edit/5
 
        public ActionResult Edit(int id)
        {
             return View(new CharityRequirementVM(charityrequirementRepository.Find(id)));
        }

        //
        // POST: /Charity/Edit/5

       [HttpPost, ValidateInput(false)]
        public ActionResult Edit(CharityRequirementVM charityrequirementVM)
        {
            if (ModelState.IsValid) {
                charityrequirementRepository.InsertOrUpdate(charityrequirementVM.CharityRequirement);
                charityrequirementRepository.Save();
                return RedirectToAction("Index");
            } else {
				return View();
			}
        }

        //
        // GET: /Charity/Delete/5
        [Authorize(Roles = "Administrator")]
        public ActionResult Delete(int id)
        {
            return View(charityrequirementRepository.Find(id));
        }

        //
        // POST: /Charity/Delete/5

        [HttpPost, ActionName("Delete")]
        [Authorize(Roles = "Administrator")]
        public ActionResult DeleteConfirmed(int id)
        {
            charityrequirementRepository.Delete(id);
            charityrequirementRepository.Save();

            return RedirectToAction("Index");
        }
    }
}

