using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using SWOG_GiveCamp.Entities;
using SWOG_GiveCamp.Models;

namespace SWOG_GiveCamp.Controllers
{   
    public class SponsorController : Controller
    {
        private SponsorContext context = new SponsorContext();

        //
        // GET: /Sponsor/
        public ViewResult Sponsors()
        {
            return View(context.Sponsors.Include(sponsor => sponsor.SponsorType).ToList());
        }
        public ViewResult Index()
        {
            return View();
        }

        //
        // GET: /Sponsor/Details/5

        [Authorize(Roles = "Administrator")]
        public ViewResult Details(int id)
        {
            Sponsor sponsor = context.Sponsors.Single(x => x.SponsorId == id);
            return View(sponsor);
        }

        //
        // GET: /Sponsor/Create
        [Authorize(Roles = "Administrator")]
        public ActionResult Create()
        {
            ViewBag.PossibleSponsorTypes = context.SponsorTypes;
            return View();
        } 

        //
        // POST: /Sponsor/Create

        [HttpPost]
        [Authorize(Roles = "Administrator")]
        public ActionResult Create(Sponsor sponsor)
        {
            if (ModelState.IsValid)
            {
                context.Sponsors.Add(sponsor);
                context.SaveChanges();
                return RedirectToAction("Index");  
            }

            ViewBag.PossibleSponsorTypes = context.SponsorTypes;
            return View(sponsor);
        }
        
        //
        // GET: /Sponsor/Edit/5
        [Authorize(Roles = "Administrator")]
        public ActionResult Edit(int id)
        {
            Sponsor sponsor = context.Sponsors.Single(x => x.SponsorId == id);
            ViewBag.PossibleSponsorTypes = context.SponsorTypes;
            return View(sponsor);
        }

        //
        // POST: /Sponsor/Edit/5

        [HttpPost]
        [Authorize(Roles = "Administrator")]
        public ActionResult Edit(Sponsor sponsor)
        {
            if (ModelState.IsValid)
            {
                context.Entry(sponsor).State = EntityState.Modified;
                context.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.PossibleSponsorTypes = context.SponsorTypes;
            return View(sponsor);
        }

        //
        // GET: /Sponsor/Delete/5
        [Authorize(Roles = "Administrator")]
        public ActionResult Delete(int id)
        {
            Sponsor sponsor = context.Sponsors.Single(x => x.SponsorId == id);
            return View(sponsor);
        }

        //
        // POST: /Sponsor/Delete/5

        [HttpPost, ActionName("Delete")]
        [Authorize(Roles = "Administrator")]
        public ActionResult DeleteConfirmed(int id)
        {
            Sponsor sponsor = context.Sponsors.Single(x => x.SponsorId == id);
            context.Sponsors.Remove(sponsor);
            context.SaveChanges();
            return RedirectToAction("Index");
        }
    }
}