using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using SWOG_GiveCamp.Entities;
using SWOG_GiveCamp;
using SWOG_GiveCamp.Models;

namespace SWOG_GiveCamp.Controllers
{   
    public class VolunteerController : Controller
    {

        //
        // GET: /Volunteer/
        public ViewResult Index()
        {
            return View();
        }
        public ViewResult Review()
        {
            return View(App.Db.Volunteers.Include(volunteer => volunteer.ExperienceLevel).Include(volunteer => volunteer.JobRoles).Include(volunteer => volunteer.Technologies).ToList());
        }

        //
        // GET: /Volunteer/Details/5

        public ViewResult Details(int id)
        {
            Volunteer volunteer = App.Db.Volunteers.Single(x => x.VolunteerID == id);
            return View(volunteer);
        }

        //
        // GET: /Volunteer/Create
        public ActionResult Signup()
        {
            return RedirectToAction("Create");
        }
        public ActionResult Create()
        {
            ViewBag.PossibleExperienceLevels = App.Db.ExperienceLevels;
            return RedirectToAction("Index");
            //return View(new VolunteerVM());
        }
        public ActionResult Register()
        {
            ViewBag.PossibleExperienceLevels = App.Db.ExperienceLevels;
            return RedirectToAction("Index"); 
            //return View("Create", new VolunteerVM());
        } 

        //
        // POST: /Volunteer/Create

        [HttpPost, ValidateInput(false)]
        [ValidateAntiForgeryToken]
        public ActionResult Create(VolunteerVM volunteerVM)
        {
            try
            {
                if (TryValidateModel(volunteerVM.Volunteer))
                {
                    App.Db.Volunteers.Add(volunteerVM.Volunteer);
                    ViewBag.Email = volunteerVM.EmailAddress;
                    App.Db.SaveChanges();
                    Models.MailRepo repo = new MailRepo();
                    repo.SendVolunteerAcknowledgement(volunteerVM);
                    return View("Success");  
                }
                else
                {
                    ViewBag.PossibleExperienceLevels = App.Db.ExperienceLevels;
                    return View(volunteerVM);
                }

            }
            catch (System.Data.Entity.Validation.DbEntityValidationException exceptio)
            {
                Elmah.ErrorSignal.FromCurrentContext().Raise(exceptio);
                ViewData.ModelState.AddModelError("unk","A data type error message prevent from saving your data.  Review your input form and try again.  Sorry, that's all I can tell you about the error.");
                return View(volunteerVM);
            }
            catch(Exception ex)
            {
                Elmah.ErrorSignal.FromCurrentContext().Raise(ex);
                return View("Oops");
            }
        }
        
        //
        // GET: /Volunteer/Edit/5
 
        public ActionResult Edit(int id)
        {
            Volunteer volunteer = App.Db.Volunteers.Single(x => x.VolunteerID == id);
            ViewBag.PossibleExperienceLevels = App.Db.ExperienceLevels;
            return View(new VolunteerVM(volunteer));
        }

        //
        // POST: /Volunteer/Edit/5

        [HttpPost]
        [Authorize(Roles = "Administrator")]
        public ActionResult Edit(VolunteerVM volunteerVM)
        {
            if (ModelState.IsValid)
            {
                App.Db.Entry(volunteerVM.Volunteer).State = EntityState.Modified;
                App.Db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.PossibleExperienceLevels = App.Db.ExperienceLevels;
            return View(volunteerVM);
        }

        //
        // GET: /Volunteer/Delete/5
        [Authorize(Roles = "Administrator")]
        public ActionResult Delete(int id)
        {
            Volunteer volunteer = App.Db.Volunteers.Single(x => x.VolunteerID == id);
            return View(volunteer);
        }

        //
        // POST: /Volunteer/Delete/5

        [HttpPost, ActionName("Delete")]
        [Authorize(Roles = "Administrator")]
        public ActionResult DeleteConfirmed(int id)
        {
            Volunteer volunteer = App.Db.Volunteers.Single(x => x.VolunteerID == id);
            App.Db.Volunteers.Remove(volunteer);
            App.Db.SaveChanges();
            return RedirectToAction("Index");
        }
    }
}