﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Web;
using DataAnnotationsExtensions;

namespace SWOG_GiveCamp.Entities
{
    public class CharityRequirementVM
    {
        private CharityRequirement _charityRequirement;

        public CharityRequirementVM()
        {
            _charityRequirement = new CharityRequirement();
            StaffTechnologies = GetStaffTechnologies();
            ProjectTechnologies = GetProjectTechnologies();
        }

        public CharityRequirementVM(CharityRequirement charityRequirement)
        {
            _charityRequirement = charityRequirement;
            StaffTechnologies = GetStaffTechnologies();
            ProjectTechnologies = GetProjectTechnologies();

        }

        public CharityRequirement CharityRequirement
        {
            get
            {
                if (StaffTechnologies != null)
                {
                    _charityRequirement.StaffTechnologies =
                        (from c in StaffTechnologies where c.IsSelected select c.Technology).ToList();
                }
                else
                {
                    _charityRequirement.StaffTechnologies = new List<Technology>();
                }
                if (ProjectTechnologies != null)
                {
                    _charityRequirement.ProjectTechnologies =
                        (from c in ProjectTechnologies where c.IsSelected select c.Technology).ToList();
                }
                else
                {
                    _charityRequirement.ProjectTechnologies = new List<Technology>();
                }
                return _charityRequirement;
            }
            set { _charityRequirement = value; }
        }

        public int CharityRequirementId
        {
            get { return _charityRequirement.CharityRequirementId; }
            set { _charityRequirement.CharityRequirementId = value; }
        }
         [Required]
        public string ContactName
        {
            get { return _charityRequirement.ContactName; }
            set { _charityRequirement.ContactName = value; }
        }
         [Required]
        public string CharityName
        {
            get { return _charityRequirement.CharityName; }
            set { _charityRequirement.CharityName = value; }
        }

        public string CallInstruction
        {
            get { return _charityRequirement.CallInstruction; }
            set { _charityRequirement.CallInstruction = value; }
        }
         [Required(ErrorMessage = "We Need to Know about your Charity")]
        public string BackgroundInformation
        {
            get { return _charityRequirement.BackgroundInformation; }
            set { _charityRequirement.BackgroundInformation = value; }
        }

        public string WorkRequested
        {
            get { return _charityRequirement.WorkRequested; }
            set { _charityRequirement.WorkRequested = value; }
        }

        public string OtherInfrastructure
        {
            get { return _charityRequirement.OtherInfrastructure; }
            set { _charityRequirement.OtherInfrastructure = value; }
        }

        public string OtherSupportSkills
        {
            get { return _charityRequirement.OtherSupportSkills; }
            set { _charityRequirement.OtherSupportSkills = value; }
        }
         [Required]
         [RegularExpression(@"((\(\d{3}\) ?)|(\d{3}-))?\d{3}-\d{4}", ErrorMessage = "Not a valid Phone Number")]
        public string PhoneNumber
        {
            get { return _charityRequirement.PhoneNumber; }
            set { _charityRequirement.PhoneNumber = value; }
        }

        public string CurrentWebURL
        {
            get { return _charityRequirement.CurrentWebURL; }
            set { _charityRequirement.CurrentWebURL = value; }
        }
        [Email]
        [Required]
        public string Email
        {
            get { return _charityRequirement.Email; }
            set { _charityRequirement.Email = value; }
        }

        public bool? Selected
        {
            get { return _charityRequirement.Selected; }
            set { _charityRequirement.Selected = value; }
        }
        public ICollection<TechnologySelectVM> StaffTechnologies { get; set; }
        public ICollection<TechnologySelectVM> ProjectTechnologies { get; set; }
        private ICollection<TechnologySelectVM> GetStaffTechnologies()
        {
            var st = new List<TechnologySelectVM>();
            foreach (var staffTechnology in App.Db.Technologies)
            {
                var s = new TechnologySelectVM(staffTechnology);
                s.IsSelected = _charityRequirement.StaffTechnologies.Contains(staffTechnology);
                st.Add(s);
            }
            return st;
        }
        private ICollection<TechnologySelectVM> GetProjectTechnologies()
        {
            var st = new List<TechnologySelectVM>();
            foreach (var staffTechnology in App.Db.Technologies)
            {
                var s = new TechnologySelectVM(staffTechnology);
                s.IsSelected = _charityRequirement.ProjectTechnologies.Contains(staffTechnology);
                st.Add(s);
            }
            return st;
        }
    }
}