﻿using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using DataAnnotationsExtensions;

namespace SWOG_GiveCamp.Entities
{
    public class VolunteerVM
    {
        private Volunteer _Volunteer;

        public VolunteerVM(Volunteer volunteer)
        {
            _Volunteer = volunteer;
        }

        public VolunteerVM()
        {
            _Volunteer = new Volunteer();
            JobRoles = GetJobRoles();
            Technologies = GetTechnologies();
        }

        public Volunteer Volunteer
        {
            get
            {
                if (Technologies != null)
                {
                    _Volunteer.Technologies = (from c in Technologies where c.IsSelected select c.Technology).ToList();
                }
                else
                {
                    _Volunteer.Technologies = new List<Technology>();
                }
                return _Volunteer;
            }
            set { _Volunteer = value; }
        }

        public int VolunteerID
        {
            get { return _Volunteer.VolunteerID; }
            set { _Volunteer.VolunteerID = value; }
        }

        [Required]
        [MaxLength(30, ErrorMessage = "Maximum 30 characters allowed")]
        public string FirstName
        {
            get { return _Volunteer.FirstName; }
            set { _Volunteer.FirstName = value; }
        }

        [Required]
        [MaxLength(30, ErrorMessage = "Maximum 30 characters allowed")]
        public string LastName
        {
            get { return _Volunteer.LastName; }
            set { _Volunteer.LastName = value; }
        }

        [MaxLength(30, ErrorMessage = "Maximum 30 characters allowed")]
        public string TeamName
        {
            get { return _Volunteer.TeamName; }
            set { _Volunteer.TeamName = value; }
        }

        [Email]
        [Required]
        [MaxLength(255, ErrorMessage = "Maximum 255 characters allowed")]
        public string EmailAddress
        {
            get { return _Volunteer.EmailAddress; }
            set { _Volunteer.EmailAddress = value; }
        }

        [Required]
        [MaxLength(50, ErrorMessage = "Maximum 50 characters allowed")]
        [RegularExpression(@"((\(\d{3}\) ?)|(\d{3}-))?\d{3}-\d{4}", ErrorMessage = "Not a valid Phone Number. use ###-###-####")]
        public string PhoneNumber
        {
            get { return _Volunteer.PhoneNumber; }
            set { _Volunteer.PhoneNumber = value; }
        }

        public bool WillBeTeamLead
        {
            get { return _Volunteer.WillBeTeamLead; }
            set { _Volunteer.WillBeTeamLead = value; }
        }

        public bool Student
        {
            get { return _Volunteer.Student; }
            set { _Volunteer.Student = value; }
        }
        [MaxLength(100,ErrorMessage = "Maximum 100 characters allowed")]
        public string JobDescription
        {
            get { return _Volunteer.JobDescription; }
            set { _Volunteer.JobDescription = value; }
        }

        public bool HasLaptop
        {
            get { return _Volunteer.HasLaptop; }
            set { _Volunteer.HasLaptop = value; }
        }

        public bool HasExtraLaptop
        {
            get { return _Volunteer.HasExtraLaptop; }
            set { _Volunteer.HasExtraLaptop = value; }
        }

        public bool GoodGuiDesigner
        {
            get { return _Volunteer.GoodGuiDesigner; }
            set { _Volunteer.GoodGuiDesigner = true; }
        }

        public int ExperienceLevelID
        {
            get { return _Volunteer.ExperienceLevelID; }
            set { _Volunteer.ExperienceLevelID = value; }
        }

        public int? YearsOfExperience
        {
            get { return _Volunteer.YearsOfExperience; }
            set { _Volunteer.YearsOfExperience = value; }
        }

        [MaxLength(50, ErrorMessage = "Maximum 50 characters allowed")]
        public string DietaryNeeds
        {
            get { return _Volunteer.DietaryNeeds; }
            set { _Volunteer.DietaryNeeds = value; }
        }

        [MaxLength(50, ErrorMessage = "Maximum 50 characters allowed")]
        public string TwitterHandle
        {
            get { return _Volunteer.TwitterHandle; }
            set { _Volunteer.TwitterHandle = value; }
        }

        [MaxLength(4000, ErrorMessage = "Maximum 4000 characters allowed")]
        public string Bio
        {
            get { return _Volunteer.Bio; }
            set { _Volunteer.Bio = value; }
        }
        
        [MaxLength(4000, ErrorMessage = "Maximum 4000 characters allowed")]
        public string Comments
        {
            get { return _Volunteer.Comments; }
            set { _Volunteer.Comments = value; }
        }

        public virtual ExperienceLevel ExperienceLevel
        {
            get { return _Volunteer.ExperienceLevel; }
            set { _Volunteer.ExperienceLevel = value; }
        }

        public virtual ICollection<JobRoleSelectVM> JobRoles { get; set; }
        public virtual ICollection<TechnologySelectVM> Technologies { get; set; }

        private ICollection<JobRoleSelectVM> GetJobRoles()
        {
            var st = new List<JobRoleSelectVM>();
            foreach (JobRole jobRole in App.Db.JobRoles)
            {
                var s = new JobRoleSelectVM(jobRole);
                s.IsSelected = _Volunteer.JobRoles.Contains(jobRole);
                st.Add(s);
            }
            return st;
        }

        private ICollection<TechnologySelectVM> GetTechnologies()
        {
            var st = new List<TechnologySelectVM>();
            foreach (Technology Technology in App.Db.Technologies)
            {
                var s = new TechnologySelectVM(Technology);
                s.IsSelected = _Volunteer.Technologies.Contains(Technology);
                st.Add(s);
            }
            return st;
        }
    }
}