﻿using System;
using System.Web;
using System.Web.Mvc;
using System.Web.Routing;
using SWOG_GiveCamp.Models;

namespace SWOG_GiveCamp
{
    // Note: For instructions on enabling IIS6 or IIS7 classic mode, 
    // visit http://go.microsoft.com/?LinkId=9394801

    public class App : HttpApplication
    {
        private const string SponsorKey = "SponsorDb.Session";
        private const string SessionKey = "Db.Session";

        public App()
        {
            BeginRequest += MvcApplication_BeginRequest;
            EndRequest += MvcApplication_EndRequest;
        }

        public static SponsorContext SponsorDb
        {
            get { return (SponsorContext) HttpContext.Current.Items[SponsorKey]; }
        }

        public static GiveCampContext Db
        {
            get { return (GiveCampContext) HttpContext.Current.Items[SessionKey]; }
        }

        private void MvcApplication_EndRequest(object sender, EventArgs e)
        {
            var disposable = HttpContext.Current.Items[SessionKey] as IDisposable;
            if (disposable != null) disposable.Dispose();
            var disposable2 = HttpContext.Current.Items[SponsorKey] as IDisposable;
            if (disposable != null) disposable.Dispose();
        }

        private void MvcApplication_BeginRequest(object sender, EventArgs e)
        {
            HttpContext.Current.Items[SessionKey] = new GiveCampContext();
            HttpContext.Current.Items[SponsorKey] = new SponsorContext();
        }

        public static void RegisterGlobalFilters(GlobalFilterCollection filters)
        {
            filters.Add(new HandleErrorAttribute());
        }

        public static void RegisterRoutes(RouteCollection routes)
        {
            routes.IgnoreRoute("{resource}.axd/{*pathInfo}");
            routes.IgnoreRoute("favicon.ico");
            routes.IgnoreRoute("{resource}.svc/{*pathInfo}");
            routes.MapRoute(
            "Sitemap",
            "sitemap.xml",
            new { controller = "Home", action = "SiteMapXml" }
            );
            routes.MapRoute(
                "Default", // Route name
                "{controller}/{action}/{id}", // URL with parameters
                new {controller = "Home", action = "Index", id = UrlParameter.Optional} // Parameter defaults
                );
        }

        protected void Application_Start()
        {
            RegisterGlobalFilters(GlobalFilters.Filters);
            RegisterRoutes(RouteTable.Routes);
        }

        protected void Application_Error(object sender, EventArgs e)
        {
            Exception exception = Server.GetLastError();
            Response.Clear();

            var httpException = exception as HttpException;

            if (httpException != null)
            {
                string action;

                switch (httpException.GetHttpCode())
                {
                    case 404:
                        // page not found
                        action = "HttpError404";
                        break;
                    case 500:
                        // server error
                        action = "HttpError500";
                        break;
                    default:
                        action = "Index";
                        break;
                }
                Elmah.ErrorSignal.FromCurrentContext().Raise(exception);
                // clear error on server
                Server.ClearError();

                Response.Redirect(String.Format("~/Error/{0}", action));
            }
        }
    }
}