using System;
using System.Data.Entity.ModelConfiguration;
using System.Data.Common;
using System.Data.Entity;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using SWOG_GiveCamp.Entities;

namespace SWOG_GiveCamp.Mapping
{
	public class CharityRequirementMap : EntityTypeConfiguration<CharityRequirement>
	{
		public CharityRequirementMap()
		{
			// Primary Key
			this.HasKey(t => t.CharityRequirementId);

			// Properties
			this.Property(t => t.ContactName)
				.IsRequired()
				.HasMaxLength(50);
				
			this.Property(t => t.CharityName)
				.IsRequired()
				.HasMaxLength(100);
				
			this.Property(t => t.CallInstruction)
				.HasMaxLength(1000);
				
			this.Property(t => t.BackgroundInformation)
				.HasMaxLength(4000);
				
			this.Property(t => t.OtherInfrastructure)
				.HasMaxLength(1000);
				
			this.Property(t => t.OtherSupportSkills)
				.HasMaxLength(1000);
				
			this.Property(t => t.PhoneNumber)
				.IsRequired()
				.HasMaxLength(50);
				
			this.Property(t => t.CurrentWebURL)
				.HasMaxLength(256);
				
			this.Property(t => t.Email)
				.IsRequired()
				.HasMaxLength(256);
				
			// Table & Column Mappings
			this.ToTable("CharityRequirements");
			this.Property(t => t.CharityRequirementId).HasColumnName("CharityRequirementId");
			this.Property(t => t.ContactName).HasColumnName("ContactName");
			this.Property(t => t.CharityName).HasColumnName("CharityName");
			this.Property(t => t.CallInstruction).HasColumnName("CallInstruction");
			this.Property(t => t.BackgroundInformation).HasColumnName("BackgroundInformation");
			this.Property(t => t.WorkRequested).HasColumnName("WorkRequested");
			this.Property(t => t.OtherInfrastructure).HasColumnName("OtherInfrastructure");
			this.Property(t => t.OtherSupportSkills).HasColumnName("OtherSupportSkills");
			this.Property(t => t.PhoneNumber).HasColumnName("PhoneNumber");
			this.Property(t => t.CurrentWebURL).HasColumnName("CurrentWebURL");
			this.Property(t => t.Email).HasColumnName("Email");
			this.Property(t => t.Selected).HasColumnName("Selected");

			// Relationships
			this.HasMany(t => t.StaffTechnologies)
			    .WithMany(t => t.CharityRequirements)
				.Map(m =>
                    {
                        m.ToTable("CharityRequirementSupportSkills");
                        m.MapLeftKey("CharityRequirementId");
                        m.MapRightKey("TechnologyId");
                    });
					
			this.HasMany(t => t.ProjectTechnologies)
			    .WithMany(t => t.CharityRequirements1)
				.Map(m =>
                    {
                        m.ToTable("CharityRequirementTechnologiesUsed");
                        m.MapLeftKey("CharityRequirementId");
                        m.MapRightKey("TechnologyId");
                    });
					
		}
	}
}

