using System;
using System.Data.Entity.ModelConfiguration;
using System.Data.Common;
using System.Data.Entity;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using SWOG_GiveCamp.Entities;

namespace SWOG_GiveCamp.Mapping
{
	public class VolunteerMap : EntityTypeConfiguration<Volunteer>
	{
		public VolunteerMap()
		{
			// Primary Key
			this.HasKey(t => t.VolunteerID);

			// Properties
			this.Property(t => t.FirstName)
				.IsRequired()
				.HasMaxLength(30);
				
			this.Property(t => t.LastName)
				.IsRequired()
				.HasMaxLength(30);
				
			this.Property(t => t.TeamName)
				.HasMaxLength(30);
				
			this.Property(t => t.EmailAddress)
				.IsRequired()
				.HasMaxLength(255);
				
			this.Property(t => t.PhoneNumber)
				.IsRequired()
				.HasMaxLength(50);
				
			this.Property(t => t.JobDescription)
				.HasMaxLength(100);
				
			this.Property(t => t.DietaryNeeds)
				.HasMaxLength(50);
				
			this.Property(t => t.TwitterHandle)
				.HasMaxLength(50);
				
			this.Property(t => t.Bio)
				.HasMaxLength(4000);
				
			this.Property(t => t.Comments)
				.HasMaxLength(4000);
				
			// Table & Column Mappings
			this.ToTable("Volunteers");
			this.Property(t => t.VolunteerID).HasColumnName("VolunteerID");
			this.Property(t => t.FirstName).HasColumnName("FirstName");
			this.Property(t => t.LastName).HasColumnName("LastName");
			this.Property(t => t.TeamName).HasColumnName("TeamName");
			this.Property(t => t.EmailAddress).HasColumnName("EmailAddress");
			this.Property(t => t.PhoneNumber).HasColumnName("PhoneNumber");
			this.Property(t => t.Student).HasColumnName("Student");
			this.Property(t => t.JobDescription).HasColumnName("JobDescription");
			this.Property(t => t.HasLaptop).HasColumnName("HasLaptop");
			this.Property(t => t.HasExtraLaptop).HasColumnName("HasExtraLaptop");
			this.Property(t => t.GoodGuiDesigner).HasColumnName("GoodGuiDesigner");
			this.Property(t => t.ExperienceLevelID).HasColumnName("ExperienceLevelID");
			this.Property(t => t.YearsOfExperience).HasColumnName("YearsOfExperience");
			this.Property(t => t.DietaryNeeds).HasColumnName("DietaryNeeds");
			this.Property(t => t.TwitterHandle).HasColumnName("TwitterHandle");
			this.Property(t => t.Bio).HasColumnName("Bio");
			this.Property(t => t.Comments).HasColumnName("Comments");

			// Relationships
			this.HasMany(t => t.JobRoles)
			    .WithMany(t => t.Volunteers)
				.Map(m =>
                    {
                        m.ToTable("VolunteerJobRoles");
                        m.MapLeftKey("VolunteerID");
                        m.MapRightKey("JobRoleID");
                    });
					
			this.HasRequired(t => t.ExperienceLevel)
				.WithMany(t => t.Volunteers)
				.HasForeignKey(d => d.ExperienceLevelID);
				
		}
	}
}

