using System;
using System.Data.Entity;
using System.Data.Entity.Infrastructure;
using System.Data.Services;
using SWOG_GiveCamp.Entities;
using SWOG_GiveCamp.Mapping;

namespace SWOG_GiveCamp
{
    [IgnoreProperties("vw_VolunteerTechnologyListing")]
	public class GiveCampContext : DbContext
	{
	    public GiveCampContext()
	    {
            this.Configuration.ProxyCreationEnabled = false;
	    }
		static GiveCampContext()
		{
            
            Database.SetInitializer(new GiveCampInitializer());
		}

		public DbSet<CharityRequirement> CharityRequirements { get; set; }
		public DbSet<ExperienceLevel> ExperienceLevels { get; set; }
		public DbSet<JobRole> JobRoles { get; set; }
		public DbSet<Technology> Technologies { get; set; }
		public DbSet<Volunteer> Volunteers { get; set; }
		public DbSet<vw_Volunteers> vw_Volunteers { get; set; }
		public DbSet<vw_VolunteerTechnologyListing> vw_VolunteerTechnologyListing { get; set; }
       
        protected override void OnModelCreating(DbModelBuilder modelBuilder)
		{
            modelBuilder.Conventions.Remove<IncludeMetadataConvention>();
			modelBuilder.Configurations.Add(new CharityRequirementMap());
			modelBuilder.Configurations.Add(new ExperienceLevelMap());
			modelBuilder.Configurations.Add(new JobRoleMap());
			modelBuilder.Configurations.Add(new TechnologyMap());
			modelBuilder.Configurations.Add(new VolunteerMap());
			modelBuilder.Configurations.Add(new vw_VolunteersMap());
			modelBuilder.Configurations.Add(new vw_VolunteerTechnologyListingMap());
		}
	}
    public class GiveCampInitializer : CreateDatabaseIfNotExists<GiveCampContext>
    {
        protected override void Seed(GiveCampContext context)
        {
            context.Technologies.Add(new Technology() {Description = "C#", DisplayOrder = 0});
            context.Technologies.Add(new Technology() { Description = "VB.net", DisplayOrder = 5 });
            context.Technologies.Add(new Technology() { Description = "Java", DisplayOrder = 10 });
            context.Technologies.Add(new Technology() { Description = "WordPress", DisplayOrder = 15 });
            context.Technologies.Add(new Technology() { Description = "Ruby", DisplayOrder = 20 });
            context.Technologies.Add(new Technology() { Description = "ASP.Net", DisplayOrder = 25 });
            context.Technologies.Add(new Technology() { Description = "CSS/Web Layout", DisplayOrder = 30 });
            context.Technologies.Add(new Technology() { Description = "PHP", DisplayOrder = 35 });
            context.Technologies.Add(new Technology() { Description = "MySQL", DisplayOrder = 40 });
            context.Technologies.Add(new Technology() { Description = "Graphics/Art", DisplayOrder = 45 });
            context.Technologies.Add(new Technology() { Description = "Project Management", DisplayOrder = 50 });
            context.Technologies.Add(new Technology() { Description = "JavaScript/JQuery", DisplayOrder = 55 });
            context.Technologies.Add(new Technology() { Description = "Python", DisplayOrder = 60 });

            context.JobRoles.Add(new JobRole() {Description = "Developer", DisplayOrder = 0});
            context.JobRoles.Add(new JobRole() {Description = "Business Analyst", DisplayOrder = 5});
            context.JobRoles.Add(new JobRole() {Description = "Project Manager", DisplayOrder = 10});
            context.JobRoles.Add(new JobRole() {Description = "General IT Support", DisplayOrder = 15});

            context.ExperienceLevels.Add(new ExperienceLevel() {Description = "None", DisplayOrder = 0});
            context.ExperienceLevels.Add(new ExperienceLevel() {Description = "Novice", DisplayOrder = 5});
            context.ExperienceLevels.Add(new ExperienceLevel() {Description = "Knowledgeable", DisplayOrder = 10});
            context.ExperienceLevels.Add(new ExperienceLevel() {Description = "Expert", DisplayOrder = 15});

            context.SaveChanges();
        }
    }
}

