﻿using System;
using System.Collections.Generic;
using System.Data.Entity;
using System.Data.Entity.Infrastructure;
using System.Linq;
using System.Web;
using SWOG_GiveCamp.Entities;
using SWOG_GiveCamp.Mapping;

namespace SWOG_GiveCamp.Models
{
    public class SponsorContext : DbContext
    {
        static SponsorContext()
		{

            Database.SetInitializer(new SponsorContextInitializer());
		}
        public DbSet<Sponsor> Sponsors { get; set; }
        public DbSet<SponsorType> SponsorTypes { get; set; }
        protected override void OnModelCreating(DbModelBuilder modelBuilder)
        {
            modelBuilder.Conventions.Remove<IncludeMetadataConvention>();
            modelBuilder.Configurations.Add(new SponsorMap());
        }
    }
    public class SponsorContextInitializer : CreateDatabaseIfNotExists<SponsorContext>
    {
        protected override void Seed(SponsorContext context)
        {
            context.SponsorTypes.Add(new SponsorType() { Description = "Cash" });
            context.SponsorTypes.Add(new SponsorType() { Description = "Product" });
            context.SaveChanges();
            context.Sponsors.Add(new Sponsor()
                                     {
                                         SponsorName = "BeyondPod",
                                         AltText = "BeyondPod",
                                         DisplayOrder = 0,
                                         ImageURL = "~/Public/Images/Sponsors/logo_beyondpod.jpg",
                                         NavigateURL = "http://www.beyondpod.mobi",
                                         SponsorTypeID = 1
                                     });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "Max Technical Training",
                AltText = "Max Technical Training",
                DisplayOrder = 5,
                ImageURL = "~/Public/Images/Sponsors/sponsor_max_train.jpg",
                NavigateURL = "http://www.maxtrain.com",
                SponsorTypeID = 1
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "Red Gate Software",
                AltText = "Red Gate Software",
                DisplayOrder = 5,
                ImageURL = "~/Public/Images/Sponsors/RGLogo_SimpleTools_OnWhite_RGB.jpg",
                NavigateURL = "http://www.red-gate.com/about/community_relations/respondent.htm?utm_source=ug&amp;utm_medium=uglogo&amp;utm_content=swgive&amp;utm_campaign=redgate",
                SponsorTypeID = 1
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "DevExpress",
                AltText = "DevExpress",
                DisplayOrder = 10,
                ImageURL = "~/Public/Images/Sponsors/DevExpresslogo.gif",
                NavigateURL = "http://www.devexpress.com/",
                SponsorTypeID = 1
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "Giving Station",
                AltText = "Giving Station",
                DisplayOrder = 15,
                ImageURL = "~/Public/Images/Sponsors/Booz_Allen_logo_black.jpg",
                NavigateURL = "http://www.boozallen.com/",
                SponsorTypeID = 1
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "Microsoft",
                AltText = "Microsoft",
                DisplayOrder = 20,
                ImageURL = "~/Public/Images/Sponsors/sponsor_microsoft.png",
                NavigateURL = "http://www.microsoft.com",
                SponsorTypeID = 1
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "Paycor",
                AltText = "Paycor",
                DisplayOrder = 25,
                ImageURL = "~/Public/Images/Sponsors/PaycorLogo.gif",
                NavigateURL = "http://www.paycor.com/",
                SponsorTypeID = 1
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "Strategic Data Systems",
                AltText = "Strategic Data Systems",
                DisplayOrder = 30,
                ImageURL = "~/Public/Images/Sponsors/SDS_logo_Company Name.jpg",
                NavigateURL = "http://www.sds-consulting.com/",
                SponsorTypeID = 2
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "City Barbeque",
                AltText = "City Barbeque",
                DisplayOrder = 35,
                ImageURL = "~/Public/Images/Sponsors/City_BBQ_logo_2c.jpg",
                NavigateURL = "http://www.citybbq.com/",
                SponsorTypeID = 2
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "DiscountASP.Net",
                AltText = "DiscountASP.Net",
                DisplayOrder = 40,
                ImageURL = "~/Public/Images/Sponsors/dasplogo_tagline.jpg",
                NavigateURL = "http://www.DiscountASP.Net",
                SponsorTypeID = 2
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "Grape City",
                AltText = "Grape City",
                DisplayOrder = 45,
                ImageURL = "~/Public/Images/Sponsors/LogoGrapeCity.png",
                NavigateURL = "http://www.grapecity.com",
                SponsorTypeID = 2
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "O'Reilly",
                AltText = "O'Reilly",
                DisplayOrder = 50,
                ImageURL = "~/Public/Images/Sponsors/LogoOReilly.gif",
                NavigateURL = "http://oreilly.com",
                SponsorTypeID = 2
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "LogicNP Software",
                AltText = "LogicNP Software",
                DisplayOrder = 55,
                ImageURL = "~/Public/Images/Sponsors/LogoLogicNP.jpg",
                NavigateURL = "http://www.ssware.com",
                SponsorTypeID = 2
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "Telerik Controls",
                AltText = "Telerik Controls",
                DisplayOrder = 60,
                ImageURL = "~/Public/Images/Sponsors/telerikLogo-web-174x69px.jpg",
                NavigateURL = "http://www.telerik.com",
                SponsorTypeID = 2
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "Wrox Publishing",
                AltText = "Wrox Publishing",
                DisplayOrder = 65,
                ImageURL = "~/Public/Images/Sponsors/New_WROX_Logo_color_rev.gif",
                NavigateURL = "http://www.WROX.com",
                SponsorTypeID = 2
            });
            context.Sponsors.Add(new Sponsor()
            {
                SponsorName = "Perpetual Technologies",
                AltText = "Perpetual Technologies",
                DisplayOrder = 65,
                ImageURL = "~/Public/Images/Sponsors/LogoPTIPerpetual.jpg",
                NavigateURL = "http://www.perptech.com/",
                SponsorTypeID = 2
            });
            context.SaveChanges();
        }
    }
}