﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Linq.Expressions;
using System.Web;
using SWOG_GiveCamp.Entities;

namespace SWOG_GiveCamp.Models
{
    public interface ISponsorRepository
    {
        IQueryable<Sponsor> Sponsors { get; }
        IQueryable<Sponsor> CashSponsors { get; }
        IQueryable<Sponsor> AllIncluding(params Expression<Func<Sponsor, object>>[] includeProperties);
        Sponsor Find(int id);
        void InsertOrUpdate(Sponsor sponsor);
        void Delete(int id);
        void Save();
    }

    public class SponsorRepository : ISponsorRepository
    {
        SponsorContext context = App.SponsorDb;

        public IQueryable<Sponsor> Sponsors
        {
            get { return context.Sponsors ; }
        }
        public IQueryable<Sponsor> CashSponsors
        {
            get { return context.Sponsors.Where(s=>s.SponsorTypeID==0); }
        }

        public IQueryable<Sponsor> AllIncluding(params Expression<Func<Sponsor, object>>[] includeProperties)
        {
            IQueryable<Sponsor> query = context.Sponsors;
            foreach (var includeProperty in includeProperties)
            {
                query = query.Include(includeProperty);
            }
            return query;
        }

        public Sponsor Find(int id)
        {
            return context.Sponsors.Find(id);
        }

        public void InsertOrUpdate(Sponsor sponsor)
        {
            if (sponsor.SponsorId == default(int))
            {
                // New entity
                context.Sponsors.Add(sponsor);
            }
            else
            {
                // Existing entity
                context.Entry(sponsor).State = EntityState.Modified;
            }
        }

        public void Delete(int id)
        {
            var sponsor = context.Sponsors.Find(id);
            context.Sponsors.Remove(sponsor);
        }

        public void Save()
        {
            context.SaveChanges();
        }
    }
}